@@ -23,6 +23,11 @@
  * $Revision: 1.17 $
  * $Date: 2013/09/19 01:30:56 $
  */
+#ifndef _SAMMA_LOG_H
+#define _SAMMA_LOG_H
+
+#include <errno.h>
+#include <string.h>
 
 #define SYSLOG_IDENT "samma"
 
@@ -156,6 +161,9 @@
 #define ERR_REGEX		"%s: Regex error.(%s)"
 #define ERR_AUTOBCC		"%s: Cannot add RcptTo.(%s):"
 
+/* harmless */
+#define LOG_HARMLESS            "harmless: source=%s, message-id=%s, sender=%s, recipients=%s"
+
 int syslog_facility(char *str);
 void init_log();
 void switch_log(char *);
@@ -165,3 +173,4 @@ int (*logfunc)(const char *, ...);
 
 #define log (*logfunc)
 
+#endif		/* _SAMMA_LOG_H */
