@@ -48,9 +48,10 @@
 #include "global.h"
 #include "mailzip_tmpl.h"
 
-static void zip_child(char **, char *, char *, char *);
 pthread_mutex_t gmime_lock = PTHREAD_MUTEX_INITIALIZER;
 
+static void zip_child(char **, char *, char *, char *);
+
 void
 free_name_list(struct name_list *head)
 {
@@ -74,6 +75,7 @@ free_rcptinfo(struct rcptinfo *info)
         for (p = info; p != NULL; p = tmpp) {
 	    tmpp = p->Next;
 	    free(p->passwd);
+	    free(p->keyword);
 	    if (p->rcptlist != NULL) {
 	        free_rcptlist(p->rcptlist);
 	    }
@@ -473,7 +475,6 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
     g_mime_object_set_header((GMimeObject *)part, CONTENTTYPE_HEADER, CONTENTTYPE_ZIP);
 #endif
 
-    g_mime_part_set_filename(part, mz->attachfilename);
 
 #ifndef GMIME26
     g_mime_part_set_encoding(part, GMIME_PART_ENCODING_BASE64);
@@ -483,6 +484,12 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
     g_mime_object_set_disposition((GMimeObject *)part, CONTENTDISPOSITION);
 #endif
 
+    g_mime_part_set_filename(part, mz->attachfilename);
+    // もしここでメモリリークが見つかった場合、修正例
+    // (文字コードのテストをしっかりすべき）
+    //g_mime_object_set_content_type_parameter((GMimeObject *)part, "filename", mz->attachfilename);
+    //g_mime_object_set_content_disposition_parameter((GMimeObject *)part, "filename", mz->attachfilename);
+
     /* open stream */
     r_stream = g_mime_stream_file_new(fp); 
 
@@ -732,8 +739,6 @@ push_attnamelist(struct name_list **head, char *str)
 }
 
 
-#define XHEADERNAME	"X-SaMMA-Enc"
-#define XHEADERVALUE	"YES"
 #define TEMPDIRNAME	"tmp"
 #define TEMPDIRLEN	3
 /*
@@ -806,7 +811,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 #ifndef GMIME26
     g_mime_message_add_header(mz->message, XHEADERNAME, XHEADERVALUE);
 #else
+#if 0   /* [2016.09.27] Add a header when sending mail. */
     g_mime_object_append_header((GMimeObject *)mz->message, XHEADERNAME, XHEADERVALUE);
+#endif
 #endif
 
     /* Get header subject */
@@ -1309,7 +1316,13 @@ mk_encpath(struct config *cfg, struct mailzip *mz)
     char *cfg_attachname = NULL;
 
     /* Switch cfg_attachname according to the run modes */
-    cfg_attachname = ismode_delete ? cfg->cf_deletelistname : cfg->cf_zipfilename;
+    if (ismode_delete) {
+        cfg_attachname = cfg->cf_deletelistname;
+    } else if (ismode_harmless) {
+        cfg_attachname = cfg->cf_zipfilename;
+    } else {
+        cfg_attachname = cfg->cf_zipfilename;
+    }
 
     /* get now time */
     time(&now);
