@@ -24,6 +24,8 @@
  * $Date: 2013/01/09 08:18:13 $
  */
 #include <libmilter/mfapi.h>
+#include <pthread.h>
+#include "global.h"
 #include "mailzip_config.h"
 #include "mailsave.h"
 
@@ -64,6 +66,11 @@
 #define MSG_ID  "Message-ID:"
 #define REF_LEN 12
 
+#define XHEADERNAME	"X-SaMMA-Enc"
+#define XHEADERVALUE	"YES"
+
+extern pthread_mutex_t gmime_lock;
+
 struct mailzip {
     const char *subject;
     char *date;
